    		* 	This domain does not make any interpretation of restrictions placed
    			by various restrictors.  We assume that restrictions are unethical unless
    			convinced otherwise.

    		*	Aptos content is subject to the discretion of the Aptos Validators.

    		* 	Extension wallet content is subject to the discretion of the extension
    			wallet producers.

    ''''
    	Declaration
    		Statement
    		Sign
    		Notification
    		Notice
    		Memo
    "'''

    ''''
    * has external links
    * requires saving packets in the browser.
    "'''

    ''''
    Once open, the party that agrees to this must take full responsibility for every play that happens on the opened trinket.
    The party agrees to allow this trinket to save bits to browser local storage.
    "'''